/******************************************************************************
 *  This is an example for our UI SHIELD with LCD
 *  UI_Shield_LCD.ino
 *  Original Creation Date: December 9, 2015
 *  This sketch uses the LiquidCrystal library.
 *  Development environment specifics:
 *  Arduino 1.7.2
 *  Arduino R3 5V
 *  UI SHIELD with LCD (Part No: INT-2575)
 *  --> http://www.rhydolabz.com
 ******************************************************************************/
#include <LiquidCrystal.h>

LiquidCrystal LCD(8, 9, 13, 12, 11, 10);          /* Initialize the library with the numbers of the interface pins */

int SW1 = 7, SW2 = 6, SW3 = 5, SW4 = 4, SW5 = 3;
int LED1 = A2, LED2 = A3, LED3 = A4;
int Buzzer = 2;
int ADC_POT = A0, Adc_Value = 0;

void setup()
{
  pinMode(LED1, OUTPUT);                /* Initialize pin A2 as an output     */
  pinMode(LED2, OUTPUT);                /* Initialize pin A3 as an output     */
  pinMode(LED3, OUTPUT);                /* Initialize pin A4 as an output     */
  pinMode(SW1, INPUT);                  /* Initialize pin D7 as an output     */
  pinMode(SW2, INPUT);                  /* Initialize pin D6 as an output     */
  pinMode(SW3, INPUT);                  /* Initialize pin D5 as an output     */
  pinMode(SW4, INPUT);                  /* Initialize pin D4 as an output     */
  pinMode(SW5, INPUT);                  /* Initialize pin D3 as an output     */
  pinMode(Buzzer, OUTPUT);              /* Initialize pin A2 as an output     */
  LCD.begin(16, 2);                     /* Initialize 16x2 LCD                */
  LCD.setCursor(0, 0);                  /* Set the cursor to column 0, line 0 */
  LCD.print("   rhydoLABZ   ");
  LCD.setCursor(0, 1);                  /* Set the cursor to column 0, line 1 */
  LCD.print("   UI SHEILD   ");
  delay(1500);                          /* Display the data for sometime      */
  LCD.clear();                          /* Clear the display                  */
}

void loop()
{
  Adc_Value = analogRead(ADC_POT);      /* Read ADC value                     */

  LCD.setCursor(0, 0);
  LCD.print("ADC: ");
  LCD.print(Adc_Value);
  LCD.setCursor(0, 1);
  LCD.print("LED: ");                   /* Status LED for ADC values          */

  if(Adc_Value > 200)                   
  {                                     /* If ADC value > 200, turn ON LED1 and display '*' on LCD 
                                           Otherwise turn off LED1                                 */
    digitalWrite(LED1, HIGH);
    LCD.setCursor(5, 1);
    LCD.print("*");
  }
  else
    digitalWrite(LED1, LOW);

  if(Adc_Value > 500)                   
  {                                     /* If ADC value > 500, turn ON LED2 and display '*' on LCD 
                                           Otherwise turn off LED2                                 */
    digitalWrite(LED2, HIGH);
    LCD.setCursor(6, 1);
    LCD.print("*");
  }
  else
    digitalWrite(LED2, LOW);            

  if(Adc_Value > 800)
  {                                     /* If ADC value > 800, turn ON LED3 and display '*' on LCD 
                                           Otherwise turn off LED3                                 */
    digitalWrite(LED3, HIGH);
    LCD.setCursor(7, 1);
    LCD.print("*");
  }
  else
    digitalWrite(LED3, LOW);
    
  delay(500);
  
  if(digitalRead(SW1) == LOW)           /* pin 7 reads LOW if SW1 is pressed          */
  {
    LCD.clear();
    LCD.setCursor(5, 0);
    LCD.print("RIGHT");                 /* Display "RIGHT" on LCD and beep the buzzer */
    BuzzerAudio();
    delay(700);
  }
  if(digitalRead(SW2) == LOW)           /* pin 6 reads LOW if SW2 is pressed          */
  {
    LCD.clear();
    LCD.setCursor(5, 0);
    LCD.print("UP");                    /* Display "UP" on LCD and beep the buzzer    */
    BuzzerAudio(); 
    delay(500);
  }
  if(digitalRead(SW3) == LOW)           /* pin 5 reads LOW if SW3 is pressed          */
  {
    LCD.clear();
    LCD.setCursor(5, 0);
    LCD.print("SELECT");                /* Display "SELECT" on LCD and beep the buzzer*/
    BuzzerAudio();
    delay(700);
  }
  if(digitalRead(SW4) == LOW)           /* pin 4 reads LOW if SW4 is pressed          */
  {
    LCD.clear();
    LCD.setCursor(5, 0);
    LCD.print("DOWN");                  /* Display "DOWN" on LCD and beep the buzzer  */
    BuzzerAudio();  
    delay(700);
  }
  if(digitalRead(SW5) == LOW)           /* pin 3 reads LOW if SW5 is pressed          */
  {
    LCD.clear();
    LCD.setCursor(5, 0);
    LCD.print("LEFT");                  /* Display "LEFT" on LCD and beep the buzzer  */
    BuzzerAudio(); 
    delay(700);
  }
  
  LCD.clear();
}

void BuzzerAudio()
{
  digitalWrite(Buzzer, HIGH);           /* Turn on buzzer */
  delay(50);
  digitalWrite(Buzzer, LOW);            /* Turn it off    */
}
